@@ -4,12 +4,6 @@
 __author__ = "Gregory Sitnin <sitnin@gmail.com>"
 __copyright__ = "Gregory Sitnin, 2011"
 
-version = "0.2.8"
-
-
-import decorators
-import tpl_funcs
-import handlers
-import session
+version = "0.3.0"
 
 UUID = r"[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
