@@ -6,11 +6,13 @@ __copyright__ = "Gregory Sitnin, 2011"
 
 
 import tornado.web
-import logging
+import json
 from pprint import pformat
 
 
 class AppStatus(tornado.web.RequestHandler):
+    """Extensible application status handler."""
+
     def test(self, reply):
         """Override to implement concrete tests.
 
