@@ -9,10 +9,9 @@ from uuid import uuid1
 from datetime import datetime
 
 
-SessionException = Exception
-
-
 class AbstractSession(object):
+    """Abstract server-side session"""
+
     def __init__(self, conn, session_id=None, auto=True, update_activity=False, collection="sessions"):
         self._data = dict()
         self._conn = conn
@@ -35,12 +34,15 @@ class AbstractSession(object):
     def exists(self):
         raise SessionException("Concrete .exists() method is not implemented")
 
+    def destroy(self):
+        raise SessionException("Concrete .destroy() method is not implemented")
+
     def update_activity(self):
         if self._update_activity:
             self._data["last_activity"] = datetime.utcnow()
 
     def get(self, key, default=None):
-        return self._data[key] if self._data.has_key(key) else default
+        return self._data[key] if key in self._data else default
 
     def set(self, key, value):
         self._data[key] = value
@@ -54,22 +56,27 @@ class AbstractSession(object):
         if self._auto:
             self.save()
 
-try:
-    import pymongo
 
-    class MongoSession(AbstractSession):
-        def save(self):
-            s = self._data
-            s["_id"] = self._session_id
-            self._conn[self._collection].save(s)
+class MongoSession(AbstractSession):
+    """Server-side session support class working with MongoDB as backend"""
 
-        def load(self):
-            loaded = self._conn[self._collection].find_one({"_id": self._session_id})
-            self._data = loaded if loaded else dict()
+    def save(self):
+        s = self._data
+        s["_id"] = self._session_id
+        self._conn[self._collection].save(s)
 
-        def exists(self):
-            session = self._conn[self._collection].find_one({"_id": self._session_id}, {"_id": 1})
-            return True if session else False
+    def load(self):
+        loaded = self._conn[self._collection].find_one({"_id": self._session_id})
+        self._data = loaded if loaded else dict()
 
-except ImportError:
+    def destroy(self):
+        self._data = dict()
+        self._conn[self._collection].remove({"_id": self._session_id})
+
+    def exists(self):
+        session = self._conn[self._collection].find_one({"_id": self._session_id}, {"_id": 1})
+        return True if session else False
+
+
+class SessionException(Exception):
     pass
